@@ -23,7 +23,12 @@ use crate::prelude::{
         BTreeSet,
         VecDeque,
     },
+    fmt,
     marker::PhantomData,
+    ops::{
+        Range,
+        RangeInclusive,
+    },
     string::String,
     vec::Vec,
 };
@@ -36,6 +41,7 @@ use crate::{
     TypeDefArray,
     TypeDefCompact,
     TypeDefPrimitive,
+    TypeDefRange,
     TypeDefSequence,
     TypeDefTuple,
     TypeInfo,
@@ -347,6 +353,26 @@ where
     }
 }
 
+impl<Idx> TypeInfo for Range<Idx>
+where
+    Idx: TypeInfo + 'static + PartialOrd + fmt::Debug,
+{
+    type Identity = Self;
+    fn type_info() -> Type {
+        TypeDefRange::new::<Idx>(false).into()
+    }
+}
+
+impl<Idx> TypeInfo for RangeInclusive<Idx>
+where
+    Idx: TypeInfo + 'static + PartialOrd + fmt::Debug,
+{
+    type Identity = Self;
+    fn type_info() -> Type {
+        TypeDefRange::new::<Idx>(true).into()
+    }
+}
+
 #[cfg(feature = "bit-vec")]
 mod bit_vec {
     use super::*;
